%define realname gettext
%define amversion 0.12 
%define name %{realname}_%{amversion}
%define version 0.12.1
%define release 3mdk
%define major 2
%define libver %{major}.3.0
%define lib_name %mklibname intl_%{amversion}_%{major} 
%define prefix /usr
%define _libtoolize /bin/true

%define enable_java 1
%{?_without_java: %define enable-java 0}

Name: %{name}
Summary: GNU libraries and utilities for producing multi-lingual messages.
Version: %{version}
Release: %{release}
License: GPL
Group: System/Internationalization
BuildRoot: %{_tmppath}/%{realname}-%{version}-buildroot 
URL: http://www.gnu.org/software/gettext/ 
Source: gettext-%{version}.tar.bz2
Source1: po-mode-init.el
# patch to not issue error messages and warnings with some charset encodings
# we support in MDK. -- pablo
Patch5: gettext-0.12.1-charsets.patch.bz2 
# patch also works and is needed with libtool-1.4
Patch8: gettext-0.12.1-libtool-1.5.patch.bz2

Requires: %{name}-base = %{version}-%{release}
Requires: %{lib_name} = %{version}-%{release}
BuildRequires:	autoconf2.5
BuildRequires:  automake1.7
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	emacs-bin
BuildRequires:	emacs-el
BuildRequires:	texinfo
BuildRequires:  gettext-devel
%if %enable_java
BuildRequires:	gcc-java
BuildRequires:	gcj-tools
%endif 
Provides: gettext = %{version} 
Conflicts: gettext < %{version}

%description  
The GNU gettext package provides a set of tools and documentation for producing
multi-lingual messages in programs. Tools include a set of conventions about
how programs should be written to support message catalogs, a directory and
file naming organization for the message catalogs, a runtime library which
supports the retrieval of translated messages, and stand-alone programs for
handling the translatable and the already translated strings. Gettext provides
an easy to use library and tools for creating, using, and modifying natural
language catalogs and is a powerful and simple method for internationalizing
programs.

If you would like to internationalize or incorporate multi-lingual messages
into programs that you're developing, you should install gettext.

This is gettext-0.12.1 and is not parallel installable.

%package -n %{lib_name}
Summary: The dynamic libintl library for the gettext package.
Group: System/Libraries
License: LGPL  
Provides: libintl 
Provides: libintl2 = %{version}
Conflicts: libintl2 < %{version}

%description -n %{lib_name}
This package contains the libintl library for the gettext package.

%package devel
Summary: GNU libraries and utilities for producing multi-lingual messages.
Group: Development/C
License: LGPL
Requires: %{name} = %{version}-%{release}
Provides: gettext-devel  = %{version}
Conflicts: gettext-devel  < %{version}


%description devel
Header files, used when the libc does not provide code of handling
multi-lingual messages.

%package base
Summary: GNU libraries and utilities for producing multi-lingual messages.
Group: System/Internationalization
Requires: %{lib_name} = %{version}-%{release}
Provides: gettext-base  = %{version}
Conflicts:  gettext-base  < %{version}

%description base
The base package which includes the gettext binary.

%if %enable_java
%package java
Summary: Java binding for GNU gettext.
Group: System/Internationalization
Requires:  %{name} = %{version}-%{release}
Conflicts:  gettext-devel < %{version}

%description java
This package contains class file that implements the main GNU libintl
functions in Java. This allows compiling GNU gettext message catalogs
into Java ResourceBundle classes.
%endif


%prep
rm -rf $RPM_BUILD_ROOT
%setup -qn  %{realname}-%{version}
%patch5 -p1 -b .more_charsets
#patch7 -p1
%patch8 -p0 -b .inst_prefix
# autoconf doesn't like "AC_IN_PATH" to happen in a variable name
find -type f | xargs env LC_CTYPE=C perl -pi -e 's/HAVE_JAVAC_IN_PATH/HAVE_JAVA_C_IN_PATH/g' 
 
%build
export WANT_AUTOCONF_2_5=1
# (cae) ###DO NOT USE configure marco if litool version is < 1.5
            ### Path needs to be set for prefix and info 
./configure --prefix=%prefix --infodir=%{_infodir} --libdir=%{_libdir} \
                 --enable-shared --with-included-gettext 
# (gc) #### DO NOT USE #### percent-make or you'll suffer so much that hell would be a pleasure for you
make
# make check is A Good Thing, but java check fails
#make check

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

# libintl.h is bundled in glibc
rm -f $RPM_BUILD_ROOT%{_includedir}/libintl.h
# locale.alias also bundled in glibc
rm -f $RPM_BUILD_ROOT%{_datadir}/locale/locale.alias
# rm empty file
rm -f gettext-runtime/intl-java/javadoc2/package-list

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el

# remove non-standard lc directories
for i in en@boldquot en@quot ; do rm -rf $RPM_BUILD_ROOT/%{_datadir}/locale/$i; done

%find_lang %{name} --all-name

# move installed doc back to %%doc
rm -rf htmldoc
mkdir htmldoc
for i in gettext-runtime/man/*.html; do
  rm -f $RPM_BUILD_ROOT%{_datadir}/doc/gettext/`basename $i`
done
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/gettext/javadoc*
mv $RPM_BUILD_ROOT%{_datadir}/doc/gettext/* $RPM_BUILD_ROOT/%{_datadir}/doc/libasprintf/* htmldoc
 
# move crucial stuff to /lib and /bin
cd $RPM_BUILD_ROOT
mkdir -p bin
mkdir -p ./%{_lib}
mv usr/bin/gettext bin
ln -s ../../bin/gettext usr/bin/gettext
mv .%{_libdir}/libintl.so.* ./%{_lib}/
ln -sf ../../%{_lib}/libintl.so.%{libver} .%{_libdir}/libintl.so   
 

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%post devel
%_install_info autosprintf.info

%preun devel
%_remove_install_info autosprintf.info

%post -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS README COPYING gettext-runtime/ABOUT-NLS gettext-runtime/BUGS NEWS THANKS gettext-tools/TODO htmldoc
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*.el
%{_bindir}/msg*
%{_bindir}/xgettext
%{_bindir}/autopoint
%{_libdir}/gettext
%exclude %{_libdir}/gettext/gnu.gettext.*
%{_infodir}/gettext.*
%{_datadir}/emacs/site-lisp/*.el*
%{_mandir}/man1/msg*
%{_mandir}/man1/xgettext*
%{_mandir}/man1/autopoint*
%{_mandir}/man3/*

%files base -f %{name}.lang
%defattr(-,root,root)
%doc gettext-runtime/man/*.1.html
/bin/gettext
%{_bindir}/gettext
%{_bindir}/ngettext  
%{_mandir}/man1/gettext*
%{_mandir}/man1/ngettext*

%files -n %{lib_name}
%defattr(-,root,root)
%doc gettext-runtime/intl/COPYING*
/%{_lib}/lib*.so.*
%{_libdir}/lib*-*.*.so
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%doc gettext-runtime/man/*.3.html 
%{_bindir}/gettextize
%{_datadir}/gettext
%exclude %{_datadir}/gettext/*.jar
%{_datadir}/aclocal/*
%{_includedir}/*
%{_infodir}/autosprintf*
%{_libdir}/lib*.a
%{_libdir}/lib*.la
# "lib*.so" cannot be used (it should be 'lib[^\.]*\.so' regexp in fact
# but using regexp is not possible here; so we list all files manually
%{_libdir}/libasprintf.so
%{_libdir}/libgettextlib.so
%{_libdir}/libgettextpo.so
%{_libdir}/libgettextsrc.so
%{_libdir}/libintl.so

%if %enable_java
%files java
%defattr(-,root,root)
%doc gettext-runtime/intl-java/javadoc* 
%{_libdir}/gettext/gnu.gettext.*
%{_datadir}/gettext/*.jar
%endif

%changelog
* Tue Aug 05 2003 Charles A Edwards <eslrahc@bellsouth.net> 0.12.1-3mdk
- add version tag to Conflict in lib pkg and Provide=version for same

* Tue Aug 05 2003 Charles A Edwards <eslrahc@bellsouth.net> 0.12.1-2mdk
- fix for distlint
  - rm locale.alias....bundled in glibc
  - fix Requires and add Conflict to java pk
- adjust Provides/Conflicts

* Fri Jul 18 2003 Charles A Edwards <eslrahc@bellsouth.net> 0.12.1-1mdk
- gettext-0.12.1
- shamelessly stolen from mdk spec and from Abel Cheung <maddog@linux.org.hk>
  with added adjustments
 